(devindex)=

# Development

## Contributing to crowsetta

This is a community driven project and everyone is welcome to contribute.

The project is hosted at the
[crowsetta GitHub repository](https://github.com/vocalpy/crowsetta).

The goal is to maintain a diverse community that's pleasant for everyone.
**Please be considerate and respectful of others**. Everyone must abide by our
[Code of Conduct](https://github.com/vocalpy/crowsetta/blob/main/CODE_OF_CONDUCT.md)
and we encourage all to read it carefully.

```{toctree}
:maxdepth: 2

contributors
```

This development documentation is adapted from the exemplary guides provided by
[numpy](https://numpy.org), [pandas](https://pandas.pydata.org),
and [PyGMT](https://www.pygmt.org).
crowsetta is built on [Scientific Python](https://scientific-python.org/>) libraries, 
such as NumPy, SciPy, and pandas, 
as well as the [pyOpenSci](https://www.pyopensci.org/) package [pandera](https://pandera.readthedocs.io/).
Please consider also contributing to these ecosystems.
